# Social validator

![CI](https://github.com/flacy/social-validator/actions/workflows/ci.yml/badge.svg)
![License](https://img.shields.io/github/license/flacy/social-validator)

### ❓ What's this
This is a library for validating data from social networks and messengers,
such as identifiers, usernames, etc.

### ⚡ Motivation
The motivation for creating this library was derived from the fact that there
is no single database to determine the restrictions of each service.
Accordingly, in order to validate the data correctly, you need to deep down
into the documentation, but sometimes even these data are not specified in it,
and you need to test the validation manually. This library is designed to
solve this problem. *Unfortunately, only for python ;(*

### 📑 Documentation
Documentation for each method is available via docstrings.
If you really need documentation as a separate page, please open issue.

### ⚠️ Roadmap
The project is under development and is moving to a stable version.
To track the status, you can [follow the link](https://github.com/users/Flacy/projects/1).

### 🛠️ Contributing
If you want to help with development, or want to see some feature, or fix a
bug, please open issue with the appropriate label first.